# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
This subpackage contains modules and packages for identifying sources in
an astronomical image.
"""

from .core import *         # noqa
from .findstars import *    # noqa
